# Manufacturing Order

{message}

| Field | Value |
|-------|-------|
| **Order ID** | {id} |
| **Order Number** | {order_no} |
| **Variant ID** | {variant_id} |
| **Planned Quantity** | {planned_quantity} |
| **Location ID** | {location_id} |
| **Status** | {status} |

## Next Steps

{next_actions_text}
